import importlib_metadata
from pprint import pprint
from gidtools.gidfiles import writejson, writeit
to_check = ['psutil']
_clean_to_check = []

for item in to_check:
    if ' ' in item:
        item = item.split(' ')[0]
    _clean_to_check.append(item)
_out_list = []
_out_dict = {}
for pack in _clean_to_check:
    x = importlib_metadata.metadata(pack).get_all('Provides-Extra')
    y = importlib_metadata.metadata(pack).get_all('Requires-Dist')
    _uninstall_string = f"call pip uninstall -q -y {pack}"
    _out_list.append(_uninstall_string)
    _out_dict[pack] = {'extras': x, 'requires': y}

writejson(_out_dict, "check.json")
writeit('test.txt', '\n'.join(_out_list))





FILE = r"D:\Dropbox\hobby\Modding\Programs\Github\My_Repos\gidlogger_rep\pyproject.toml"


with open(FILE, 'r') as cvf:
    _content = cvf.read()

with open(FILE, 'w') as ncvf:
    for line in _content.splitlines():
        if '==' in line:

            line = line.replace('==', '>=')
        ncvf.write(line + '\n')



from github import Github, GithubException
from dotenv import load_dotenv
import os
from pprint import pprint
from datetime import datetime, timedelta
load_dotenv(r"D:\Dropbox\hobby\Modding\Programs\Github\My_Repos\Antipetros_Discord_Bot\Antipetros_Discord_Bot\.env")
GITHUB_TOKEN = os.getenv('GITHUB_TOKEN')
REPO = 'official-antistasi-community/A3-Antistasi'
NOW = datetime.now()


def get_issues():
    github = Github(login_or_token=GITHUB_TOKEN)
    user = github.get_user()
    repo = github.get_repo(REPO)
    _time = NOW - timedelta(days=2)

    _issues = repo.get_issues(state='open', since=_time)
    for issue in _issues:
        print(issue.title)


if __name__ == '__main__':
    get_issues()




# region [Imports]

# * Standard Library Imports -->
import os
import sys
import logging
from logging import handlers
from functools import wraps

# endregion [Imports]

# region [TOC]


# endregion [TOC]


# region [Constants]

__updated__ = '2020-11-01 21:25:58'


# endregion [Constants]

# region[Global_Functions]

def pathmaker(first_segment, *in_path_segments, rev=False):
    """
    Normalizes input path or path fragments, replaces '\\\\' with '/' and combines fragments.

    Parameters
    ----------
    first_segment : str
        first path segment, if it is 'cwd' gets replaced by 'os.getcwd()'
    rev : bool, optional
        If 'True' reverts path back to Windows default, by default None

    Returns
    -------
    str
        New path from segments and normalized.
    """
    _first = os.getcwd() if first_segment == 'cwd' else first_segment
    _path = os.path.join(_first, *in_path_segments)
    _path = _path.replace('\\\\', '/')
    _path = _path.replace('\\', '/')
    if rev is True:
        _path = _path.replace('/', '\\')

    return _path.strip()
# endregion[Global_Functions]

# region [Logging_Messages]


def imported(in_name):
    return (f"succesfully imported [-{in_name}-]")


def DEPRECATED(in_alternative=None):
    if in_alternative is None:
        _msg = "!!!!!!!!!DEPRECATED FUNCTION!!!!!!!!!, stop using it!"
    else:
        _msg = f"!!!!!!!!!DEPRECATED FUNCTION!!!!!!!!!, use [{in_alternative}] instead!"
    return _msg


def NEWRUN():
    return "# " + "*-$-" * 6 + "* --> NEW_RUN <-- " + "*-?-" * 6 + "* #"


def class_initiated(in_class, use=None):
    if use == 'repr':
        _string = repr(in_class)
    elif use == 'str':
        _string = str(in_class)
    else:
        _string = in_class.__class__.__name__
    return f"finished initiating {_string} class"


def called(function_name):
    return f"{function_name} was called"


def completed(function_name):
    return f"{function_name} completed"

# endregion [Logging_Messages]


# region [Logging_Settings]


def aux_logger(in_name):
    return logging.getLogger('main').getChild(in_name)


def main_logger(in_file_name, in_level, in_back_up=2):

    _out = logging.getLogger('main')
    _out.setLevel(getattr(logging, in_level.upper()))
    formatter = logging.Formatter('%(asctime)s : %(levelname)s : %(name)s : %(lineno)s : %(funcName)s : %(message)s')
    should_roll_over = os.path.isfile(in_file_name)
    handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up)
    handler.namer = std_namer
    if should_roll_over:
        handler.doRollover()
    handler.setFormatter(formatter)
    _out.addHandler(handler)

    return _out


def main_logger_stdout(in_level, message_sep: int = 10):

    _out = logging.getLogger('main')
    _out.setLevel(getattr(logging, in_level.upper()))
    formatter = logging.Formatter(fmt='[{levelname}][{funcName}] --> ' + ' ' * message_sep + '{message}', style='{')
    handler = logging.StreamHandler(sys.stdout)
    handler.setFormatter(formatter)
    _out.addHandler(handler)

    return _out

# endregion [Logging_Settings]


# region [Logging_Functions]


def std_namer(name):
    _nameparts = name.split('.')
    _path, _basename = _nameparts[0].rsplit('\\', 1)
    return pathmaker(_path, 'old_logs', f'{_basename}_{_nameparts[2]}.{_nameparts[1]}')


def log_folderer(in_log_file_name, in_main_log_folder='logs', in_log_folder_directory=None):
    _cwd = pathmaker(os.getcwd()) if in_log_folder_directory is None else pathmaker(in_log_folder_directory)
    _path_to_old_folder = pathmaker(_cwd, in_main_log_folder, 'old_logs')
    if os.path.exists(_path_to_old_folder) is False:
        os.makedirs(_path_to_old_folder)
    return pathmaker(_cwd, in_main_log_folder, in_log_file_name + ".log")


def log_args(function):
    @wraps(function)
    def wrapper(*args, **kwargs):
        _log = logging.getLogger('main')
        _log.debug('started executing %s: --> %s <--, with arguments: %s, %s %s', type(function).__name__, function.__name__, ', '.join(map(str, args)), ', '.join([f"{str(key)}={str(value)}" for key, value in kwargs.items()]), '-' * 50)
        return function(*args, **kwargs)
    return wrapper


# endregion [Logging_Functions]


# region [Logging_Class_1]


# endregion [Logging_Class_1]
if __name__ == "__main__":
    pass



# * Standard Library Imports -->
import os
import sys
from dotenv import load_dotenv
load_dotenv()
from multiprocessing import Pool, cpu_count
THIS_FILE_DIR = os.path.abspath(os.path.dirname(__file__))
STARTFOLDER = os.path.dirname(THIS_FILE_DIR)
RESSOURCE_NAME = os.getenv('RESNAME')
RESSOURCE_RELATIVE_PATH = os.getenv('RELRESPATH')


def find_files():
    for dirname, _, filelist in os.walk(STARTFOLDER):
        for _file in filelist:
            if _file.endswith('.py') and _file.startswith('Ui_'):
                _path = os.path.join(dirname, _file).replace('\\\\', '/').replace('\\', '/')
                with open(_path, 'r') as _contentfile:
                    _content = _contentfile.read()
                yield [_path, _content]


def change_files(invars):
    _linecontent = invars[1].splitlines()
    _new_content_lines = []
    for line in _linecontent:
        if "QtCore.QMetaObject.connectSlotsByName(" in line:
            print(f"changing connectbyname in file '{invars[0]}'")
        elif RESSOURCE_NAME in line:
            _new_content_lines.append("import " + RESSOURCE_RELATIVE_PATH)
            print(f"changing ressourcepath in file '{invars[0]}'")
        else:
            _new_content_lines.append(line)
    return [invars[0], '\n'.join(_new_content_lines)]


def save(path, content):
    with open(path, 'w') as newcontent:
        newcontent.write(content)


if __name__ == '__main__':

    results = map(change_files, find_files())
    for _path, _content in results:
        save(_path, _content)



# * Standard Library Imports -->
import os
import re
THIS_FILE_DIR = os.path.abspath(os.path.dirname(__file__))
REQU_DEV_FILE = "../requirements_dev.txt"
REQU_NORM_FILE = "../requirements.txt"
PYPROJECTTOML = "../pyproject.toml"
old_cwd = os.getcwd()
REQUIRES_REGEX = re.compile(r"(?<=\[tool\.flit\.metadata\]\n)(?:.*?)(requires = \[.*?\])", re.DOTALL)


def writeit(in_file, in_data, append=False, in_encoding='utf-8', in_errors=None):
    """
    Writes to a file.

    Parameters
    ----------
    in_file : str
        The target file path
    in_data : str
        The data to write
    append : bool, optional
        If True appends the data to the file, by default False
    in_encoding : str, optional
        Sets the encoding, by default 'utf-8'
    """
    _write_type = 'w' if append is False else 'a'
    with open(in_file, _write_type, encoding=in_encoding, errors=in_errors,) as _wfile:
        _wfile.write(in_data)


def readit(in_file, per_lines=False, in_encoding='utf-8', in_errors=None):
    """
    Reads a file.

    Parameters
    ----------
    in_file : str
        A file path
    per_lines : bool, optional
        If True, returns a list of all lines, by default False
    in_encoding : str, optional
        Sets the encoding, by default 'utf-8'
    in_errors : str, optional
        How to handle encoding errors, either 'strict' or 'ignore', by default 'strict'

    Returns
    -------
    str/list
        the read in file as string or list (if per_lines is True)
    """
    with open(in_file, 'r', encoding=in_encoding, errors=in_errors) as _rfile:
        _content = _rfile.read()
    if per_lines is True:
        _content = _content.splitlines()

    return _content


def convert(use_requirements_txt: bool):
    os.chdir(THIS_FILE_DIR)
    _out_list = []
    dev_lines = readit(REQU_DEV_FILE, per_lines=True)
    for line in dev_lines:
        if line != '' and 'git+' not in line and '#' not in line and 'flit' not in line:
            _out_list.append(line.strip())
    if use_requirements_txt is True:
        writeit(REQU_NORM_FILE, '\n'.join(_out_list))
    else:
        convert_and_replace_to_toml(_out_list)
    os.chdir(old_cwd)


def convert_and_replace_to_toml(in_list):
    toml_content = readit(PYPROJECTTOML)
    _requires_part = REQUIRES_REGEX.search(toml_content).group(1)
    _new_requires = "requires = [\n"
    for line in in_list:
        line = f'\t"{line}",\n'
        _new_requires += line
    _new_requires += ']\n'
    _new_content = toml_content.replace(_requires_part, _new_requires)
    writeit(PYPROJECTTOML, _new_content)


if __name__ == '__main__':
    convert(False)



from setuptools import setup, find_packages
import os


# region[Constants]
GID_LOGGER_AUTHOR = ['Giddius']
GID_LOGGER_SHORT_DESCRIPTION = 'WiP'
GID_LOGGER_LONG_DESCRIPTION_FILE = 'README.md'
GID_LOGGER_VERSION = "0.1.0"
GID_LOGGER_LICENSE = 'MIT'
GID_LOGGER_ENTRY_POINTS = {}
GID_LOGGER_URL = ''
GID_LOGGER_REQUIREMENTS_FILE = 'requirements.txt'
# endregion[Constants]


def get_dependencies():
    # sourcery skip: inline-immediately-returned-variable, list-comprehension
    _out = []
    if os.path.isfile(GID_LOGGER_REQUIREMENTS_FILE) is True:
        with open(GID_LOGGER_REQUIREMENTS_FILE, 'r', errors='replace') as fileobject:
            _temp_list = fileobject.read().splitlines()

        for line in _temp_list:
            if line != '' and line.startswith('#') is False:
                _out.append(line)
    return _out


def get_long_description_type():
    _type_dict = {
        'md': 'text/markdown',
        'rst': 'text/x-rst',
        'txt': 'text/plain'
    }
    _ext = GID_LOGGER_LONG_DESCRIPTION_FILE.split('.')[-1]
    return _type_dict.get(_ext, 'text/plain')


def get_version():
    return GID_LOGGER_VERSION


def get_short_description():
    return GID_LOGGER_SHORT_DESCRIPTION


def get_long_description():
    with open(GID_LOGGER_LONG_DESCRIPTION_FILE, 'r', errors='replace') as fileobject:
        _out = fileobject.read()
    return _out


def get_url():
    return GID_LOGGER_URL


def get_author():
    return GID_LOGGER_AUTHOR


def get_license():
    return GID_LOGGER_LICENSE


def get_entry_points():
    return GID_LOGGER_ENTRY_POINTS


setup(name='gidlogger',
      version=get_version(),
      description=get_short_description(),
      long_description=get_long_description(),
      long_description_content_type=get_long_description_type(),
      url=get_url(),
      author=get_author(),
      license=get_license(),
      packages=find_packages(),
      install_requires=get_dependencies(),
      include_package_data=True,
      entry_points=get_entry_points(),
      options={"bdist_wheel": {"universal": True}}
      )



from dotenv import load_dotenv
import os
from gidtools.gidfiles import writeit, pathmaker

load_dotenv()


WORKSPACEDIR = os.getenv('WORKSPACEDIR')


def produce_inits():
    for dirname, folderlist, filelist in os.walk(pathmaker(WORKSPACEDIR, 'Antipetros_Discord_Bot')):
        if '__init__.py' not in filelist:
            writeit(pathmaker(dirname, '__init__.py'), '')


if __name__ == '__main__':
    produce_inits()
